@@ -4,17 +4,17 @@
 use std::collections::{BTreeMap, BTreeSet};
 use std::convert::TryInto;
 
-use anyhow::{anyhow, Context};
+use anyhow::anyhow;
 use bitfield::BitField;
 use cid::Cid;
 use fil_actors_runtime::runtime::Policy;
 use fil_actors_runtime::{ActorDowncast, Array};
 use fvm_ipld_amt::{Error as AmtError, ValueMut};
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
 use fvm_shared::bigint::bigint_ser;
+use fvm_shared::blockstore::Blockstore;
 use fvm_shared::clock::{ChainEpoch, QuantSpec};
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::tuple::*;
 use fvm_shared::sector::{SectorNumber, SectorSize};
 use num_traits::{Signed, Zero};
 
@@ -163,10 +163,7 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
     /// Epochs provided to subsequent method calls will be quantized upwards to quanta mod offsetSeed before being
     /// written to/read from queue entries.
     pub fn new(store: &'db BS, root: &Cid, quant: QuantSpec) -> Result<Self, AmtError> {
-        Ok(Self {
-            amt: Array::load(root, store)?,
-            quant,
-        })
+        Ok(Self { amt: Array::load(root, store)?, quant })
     }
 
     /// Adds a collection of sectors to their on-time target expiration entries (quantized).
@@ -182,7 +179,7 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
         let mut total_sectors = Vec::<BitField>::new();
 
         for group in group_new_sectors_by_declared_expiration(sector_size, sectors, self.quant) {
-            let sector_numbers = BitField::try_from_bits(group.sectors)?;
+            let sector_numbers: BitField = group.sectors.iter().copied().collect();
 
             self.add(
                 group.epoch,
@@ -261,8 +258,8 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
                 expiring_power += &group.sector_epoch_set.power;
             } else {
                 // Remove sectors from on-time expiry and active power.
-                let sectors_bitfield =
-                    BitField::try_from_bits(group.sector_epoch_set.sectors.iter().copied())?;
+                let sectors_bitfield: BitField =
+                    group.sector_epoch_set.sectors.iter().copied().collect();
                 group.expiration_set.on_time_sectors -= &sectors_bitfield;
                 group.expiration_set.on_time_pledge -= &group.sector_epoch_set.pledge;
                 group.expiration_set.active_power -= &group.sector_epoch_set.power;
@@ -279,7 +276,7 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
 
         if !sectors_total.is_empty() {
             // Add sectors to new expiration as early-terminating and faulty.
-            let early_sectors = BitField::try_from_bits(sectors_total)?;
+            let early_sectors: BitField = sectors_total.iter().copied().collect();
             self.add(
                 new_expiration,
                 &BitField::new(),
@@ -378,14 +375,14 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
             let on_time_sectors: BTreeSet<SectorNumber> = expiration_set
                 .on_time_sectors
                 .bounded_iter(ENTRY_SECTORS_MAX)
-                .context("too many sectors to reschedule")?
+                .map_err(|e| anyhow!(e))?
                 .map(|i| i as SectorNumber)
                 .collect();
 
             let early_sectors: BTreeSet<SectorNumber> = expiration_set
                 .early_sectors
                 .bounded_iter(ENTRY_SECTORS_MAX)
-                .context("too many sectors to reschedule")?
+                .map_err(|e| anyhow!(e))?
                 .map(|i| i as SectorNumber)
                 .collect();
 
@@ -426,10 +423,7 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
         })?;
 
         if !remaining.is_empty() {
-            return Err(anyhow!(
-                "sectors not found in expiration queue: {:?}",
-                remaining
-            ));
+            return Err(anyhow!("sectors not found in expiration queue: {:?}", remaining));
         }
 
         // Re-schedule the removed sectors to their target expiration.
@@ -482,13 +476,13 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
         // ADDRESSED_SECTORS_MAX is defined as 25000, so this will not error.
         let faults_map: BTreeSet<_> = faults
             .bounded_iter(policy.addressed_sectors_max)
-            .context("too many faults to expand")?
+            .map_err(|e| anyhow!("failed to expand faults: {}", e))?
             .map(|i| i as SectorNumber)
             .collect();
 
         let recovering_map: BTreeSet<_> = recovering
             .bounded_iter(policy.addressed_sectors_max)
-            .context("too many recoveries to expand")?
+            .map_err(|e| anyhow!("failed to expand recoveries: {}", e))?
             .map(|i| i as SectorNumber)
             .collect();
 
@@ -530,14 +524,14 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
             let on_time_sectors: BTreeSet<SectorNumber> = expiration_set
                 .on_time_sectors
                 .bounded_iter(ENTRY_SECTORS_MAX)
-                .context("too many on-time sectors to expand")?
+                .map_err(|e| anyhow!(e))?
                 .map(|i| i as SectorNumber)
                 .collect();
 
             let early_sectors: BTreeSet<SectorNumber> = expiration_set
                 .early_sectors
                 .bounded_iter(ENTRY_SECTORS_MAX)
-                .context("too many early sectors to expand")?
+                .map_err(|e| anyhow!(e))?
                 .map(|i| i as SectorNumber)
                 .collect();
 
@@ -586,10 +580,7 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
         })?;
 
         if !remaining.is_empty() {
-            return Err(anyhow!(
-                "sectors not found in expiration queue: {:?}",
-                remaining
-            ));
+            return Err(anyhow!("sectors not found in expiration queue: {:?}", remaining));
         }
 
         Ok((removed, recovering_power))
@@ -643,13 +634,7 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
         let mut expiration_set = self.may_get(epoch)?;
 
         expiration_set
-            .add(
-                on_time_sectors,
-                early_sectors,
-                pledge,
-                active_power,
-                faulty_power,
-            )
+            .add(on_time_sectors, early_sectors, pledge, active_power, faulty_power)
             .map_err(|e| anyhow!("failed to add expiration values for epoch {}: {}", epoch, e))?;
 
         self.must_update(epoch, expiration_set)?;
@@ -673,20 +658,10 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
             .ok_or_else(|| anyhow!("missing expected expiration set at epoch {}", epoch))?
             .clone();
         expiration_set
-            .remove(
-                on_time_sectors,
-                early_sectors,
-                pledge,
-                active_power,
-                faulty_power,
-            )
+            .remove(on_time_sectors, early_sectors, pledge, active_power, faulty_power)
             .map_err(|e| {
-                anyhow!(
-                    "failed to remove expiration values for queue epoch {}: {}",
-                    epoch,
-                    e
-                )
-            })?;
+            anyhow!("failed to remove expiration values for queue epoch {}: {}", epoch, e)
+        })?;
 
         self.must_update_or_delete(epoch, expiration_set)?;
         Ok(())
@@ -697,15 +672,15 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
         sectors: &[SectorOnChainInfo],
         sector_size: SectorSize,
     ) -> anyhow::Result<(BitField, PowerPair, TokenAmount)> {
-        let mut removed_sector_numbers = Vec::<u64>::new();
+        let mut removed_sector_numbers = BitField::new();
         let mut removed_power = PowerPair::zero();
         let mut removed_pledge = TokenAmount::zero();
 
         // Group sectors by their expiration, then remove from existing queue entries according to those groups.
         let groups = self.find_sectors_by_expiration(sector_size, sectors)?;
         for group in groups {
-            let sectors_bitfield =
-                BitField::try_from_bits(group.sector_epoch_set.sectors.iter().copied())?;
+            let sectors_bitfield: BitField =
+                group.sector_epoch_set.sectors.iter().copied().collect();
             self.remove(
                 group.sector_epoch_set.epoch,
                 &sectors_bitfield,
@@ -715,17 +690,15 @@ impl<'db, BS: Blockstore> ExpirationQueue<'db, BS> {
                 &group.sector_epoch_set.pledge,
             )?;
 
-            removed_sector_numbers.extend(&group.sector_epoch_set.sectors);
+            for n in group.sector_epoch_set.sectors {
+                removed_sector_numbers.set(n);
+            }
 
             removed_power += &group.sector_epoch_set.power;
             removed_pledge += &group.sector_epoch_set.pledge;
         }
 
-        Ok((
-            BitField::try_from_bits(removed_sector_numbers)?,
-            removed_power,
-            removed_pledge,
-        ))
+        Ok((removed_sector_numbers, removed_power, removed_pledge))
     }
 
     /// Traverses the entire queue with a callback function that may mutate entries.
@@ -908,10 +881,7 @@ fn group_new_sectors_by_declared_expiration<'a>(
 
     for sector in sectors {
         let q_expiration = quant.quantize_up(sector.expiration);
-        sectors_by_expiration
-            .entry(q_expiration)
-            .or_default()
-            .push(sector);
+        sectors_by_expiration.entry(q_expiration).or_default().push(sector);
     }
 
     // The result is sorted by expiration because the BTreeMap iterates in sorted order.
@@ -974,10 +944,7 @@ fn group_expiration_set(
 fn check_no_early_sectors(set: &BTreeSet<u64>, es: &ExpirationSet) -> anyhow::Result<()> {
     for u in es.early_sectors.iter() {
         if set.contains(&(u as u64)) {
-            return Err(anyhow!(
-                "Invalid attempt to group sector {} with an early expiration",
-                u
-            ));
+            return Err(anyhow!("Invalid attempt to group sector {} with an early expiration", u));
         }
     }
     Ok(())
