@@ -1,5 +1,3 @@
-use std::convert::TryInto;
-
 use fil_actors_runtime::test_utils::*;
 use fil_actors_runtime::INIT_ACTOR_ADDR;
 
@@ -8,9 +6,10 @@ use fil_actor_miner::{
     Actor, Deadline, Deadlines, Method, MinerConstructorParams as ConstructorParams, State,
 };
 
-use fvm_ipld_encoding::{BytesDe, CborStore, RawBytes};
 use fvm_shared::address::Address;
+use fvm_shared::blockstore::CborStore;
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::{blake2b_256, BytesDe, RawBytes};
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{RegisteredPoStProof, SectorSize};
 
@@ -30,17 +29,6 @@ struct TestEnv {
     rt: MockRuntime,
 }
 
-fn blake2b_256(data: &[u8]) -> [u8; 32] {
-    blake2b_simd::Params::new()
-        .hash_length(32)
-        .to_state()
-        .update(data)
-        .finalize()
-        .as_bytes()
-        .try_into()
-        .expect("fixed array size")
-}
-
 fn prepare_env() -> TestEnv {
     let mut env = TestEnv {
         receiver: Address::new_id(1000),
@@ -54,18 +42,10 @@ fn prepare_env() -> TestEnv {
     };
 
     env.rt.receiver = env.receiver;
-    env.rt
-        .actor_code_cids
-        .insert(env.owner, *ACCOUNT_ACTOR_CODE_ID);
-    env.rt
-        .actor_code_cids
-        .insert(env.worker, *ACCOUNT_ACTOR_CODE_ID);
-    env.rt
-        .actor_code_cids
-        .insert(env.control_addrs[0], *ACCOUNT_ACTOR_CODE_ID);
-    env.rt
-        .actor_code_cids
-        .insert(env.control_addrs[1], *ACCOUNT_ACTOR_CODE_ID);
+    env.rt.actor_code_cids.insert(env.owner, *ACCOUNT_ACTOR_CODE_ID);
+    env.rt.actor_code_cids.insert(env.worker, *ACCOUNT_ACTOR_CODE_ID);
+    env.rt.actor_code_cids.insert(env.control_addrs[0], *ACCOUNT_ACTOR_CODE_ID);
+    env.rt.actor_code_cids.insert(env.control_addrs[1], *ACCOUNT_ACTOR_CODE_ID);
     env.rt.hash_func = Box::new(blake2b_256);
     env.rt.caller = *INIT_ACTOR_ADDR;
     env.rt.caller_type = *INIT_ACTOR_CODE_ID;
@@ -95,15 +75,12 @@ fn simple_construction() {
         RawBytes::default(),
         TokenAmount::from(0),
         RawBytes::serialize(env.worker_key).unwrap(),
-        ExitCode::OK,
+        ExitCode::Ok,
     );
 
     let result = env
         .rt
-        .call::<Actor>(
-            Method::Constructor as u64,
-            &RawBytes::serialize(params).unwrap(),
-        )
+        .call::<Actor>(Method::Constructor as u64, &RawBytes::serialize(params).unwrap())
         .unwrap();
     assert_eq!(result.bytes().len(), 0);
     env.rt.verify();
@@ -116,10 +93,7 @@ fn simple_construction() {
     assert_eq!(env.control_addrs, info.control_addresses);
     assert_eq!(env.peer_id, info.peer_id);
     assert_eq!(env.multiaddrs, info.multi_address);
-    assert_eq!(
-        RegisteredPoStProof::StackedDRGWindow32GiBV1,
-        info.window_post_proof_type
-    );
+    assert_eq!(RegisteredPoStProof::StackedDRGWindow32GiBV1, info.window_post_proof_type);
     assert_eq!(SectorSize::_32GiB, info.sector_size);
     assert_eq!(2349, info.window_post_partition_sectors);
 
@@ -135,12 +109,7 @@ fn simple_construction() {
     let dl_idx = (env.rt.epoch - proving_period_start) / env.rt.policy.wpost_challenge_window;
     assert_eq!(dl_idx as u64, state.current_deadline);
 
-    let deadlines = env
-        .rt
-        .store
-        .get_cbor::<Deadlines>(&state.deadlines)
-        .unwrap()
-        .unwrap();
+    let deadlines = env.rt.store.get_cbor::<Deadlines>(&state.deadlines).unwrap().unwrap();
     for i in 0..env.rt.policy.wpost_period_deadlines {
         let c = deadlines.due[i as usize];
         let deadline = env.rt.store.get_cbor::<Deadline>(&c).unwrap().unwrap();
@@ -166,12 +135,8 @@ fn control_addresses_are_resolved_during_construction() {
     let control2id = Address::new_id(655);
 
     env.control_addrs = vec![control1, control2];
-    env.rt
-        .actor_code_cids
-        .insert(control1id, *ACCOUNT_ACTOR_CODE_ID);
-    env.rt
-        .actor_code_cids
-        .insert(control2id, *ACCOUNT_ACTOR_CODE_ID);
+    env.rt.actor_code_cids.insert(control1id, *ACCOUNT_ACTOR_CODE_ID);
+    env.rt.actor_code_cids.insert(control2id, *ACCOUNT_ACTOR_CODE_ID);
     env.rt.id_addresses.insert(control1, control1id);
     env.rt.id_addresses.insert(control2, control2id);
 
@@ -183,15 +148,12 @@ fn control_addresses_are_resolved_during_construction() {
         RawBytes::default(),
         TokenAmount::from(0),
         RawBytes::serialize(env.worker_key).unwrap(),
-        ExitCode::OK,
+        ExitCode::Ok,
     );
 
     let result = env
         .rt
-        .call::<Actor>(
-            Method::Constructor as u64,
-            &RawBytes::serialize(params).unwrap(),
-        )
+        .call::<Actor>(Method::Constructor as u64, &RawBytes::serialize(params).unwrap())
         .unwrap();
     assert_eq!(result.bytes().len(), 0);
     env.rt.verify();
@@ -210,9 +172,7 @@ fn fails_if_control_address_is_not_an_account_actor() {
 
     let control1 = Address::new_id(501);
     env.control_addrs = vec![control1];
-    env.rt
-        .actor_code_cids
-        .insert(control1, *PAYCH_ACTOR_CODE_ID);
+    env.rt.actor_code_cids.insert(control1, *PAYCH_ACTOR_CODE_ID);
 
     let params = constructor_params(&env);
     env.rt.expect_validate_caller_addr(vec![*INIT_ACTOR_ADDR]);
@@ -222,17 +182,14 @@ fn fails_if_control_address_is_not_an_account_actor() {
         RawBytes::default(),
         TokenAmount::from(0),
         RawBytes::serialize(env.worker_key).unwrap(),
-        ExitCode::OK,
+        ExitCode::Ok,
     );
 
     let result = env
         .rt
-        .call::<Actor>(
-            Method::Constructor as u64,
-            &RawBytes::serialize(params).unwrap(),
-        )
+        .call::<Actor>(Method::Constructor as u64, &RawBytes::serialize(params).unwrap())
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
+    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
     env.rt.verify();
 }
 
@@ -246,12 +203,9 @@ fn test_construct_with_invalid_peer_id() {
 
     let result = env
         .rt
-        .call::<Actor>(
-            Method::Constructor as u64,
-            &RawBytes::serialize(params).unwrap(),
-        )
+        .call::<Actor>(Method::Constructor as u64, &RawBytes::serialize(params).unwrap())
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
+    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
     env.rt.verify();
 }
 
@@ -268,12 +222,9 @@ fn fails_if_control_addresses_exceeds_maximum_length() {
 
     let result = env
         .rt
-        .call::<Actor>(
-            Method::Constructor as u64,
-            &RawBytes::serialize(params).unwrap(),
-        )
+        .call::<Actor>(Method::Constructor as u64, &RawBytes::serialize(params).unwrap())
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
+    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
     env.rt.verify();
 }
 
@@ -282,8 +233,7 @@ fn test_construct_with_large_multiaddr() {
     let mut env = prepare_env();
     env.multiaddrs = Vec::new();
     for _ in 0..100 {
-        env.multiaddrs
-            .push(BytesDe(vec![0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11]));
+        env.multiaddrs.push(BytesDe(vec![0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11]));
     }
 
     let params = constructor_params(&env);
@@ -291,12 +241,9 @@ fn test_construct_with_large_multiaddr() {
 
     let result = env
         .rt
-        .call::<Actor>(
-            Method::Constructor as u64,
-            &RawBytes::serialize(params).unwrap(),
-        )
+        .call::<Actor>(Method::Constructor as u64, &RawBytes::serialize(params).unwrap())
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
+    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
     env.rt.verify();
 }
 
@@ -312,11 +259,8 @@ fn test_construct_with_empty_multiaddr() {
 
     let result = env
         .rt
-        .call::<Actor>(
-            Method::Constructor as u64,
-            &RawBytes::serialize(params).unwrap(),
-        )
+        .call::<Actor>(Method::Constructor as u64, &RawBytes::serialize(params).unwrap())
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
+    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
     env.rt.verify();
 }
